@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package HTTP::BrowserDetect;
-$HTTP::BrowserDetect::VERSION = '1.73';
+$HTTP::BrowserDetect::VERSION = '1.74';
 use vars qw(@ALL_TESTS);
 
 # Operating Systems
@@ -121,46 +121,47 @@ our @ENGINE_TESTS = qw(
 # https://support.google.com/webmasters/answer/1061943?hl=en
 
 my %ROBOTS = (
-    ahrefs         => 'Ahrefs',
-    altavista      => 'AltaVista',
-    askjeeves      => 'AskJeeves',
-    baidu          => 'Baidu Spider',
-    curl           => 'curl',
-    facebook       => 'Facebook',
-    getright       => 'GetRight',
-    google         => 'Google',
-    googleadsbot   => 'Google AdsBot',
-    googleadsense  => 'Google AdSense',
-    googlebotimage => 'Googlebot Images',
-    googlebotnews  => 'Googlebot News',
-    googlebotvideo => 'Googlebot Video',
-    googlemobile   => 'Google Mobile',
-    icab           => 'iCab',
-    infoseek       => 'InfoSeek',
-    linkchecker    => 'LinkChecker',
-    linkexchange   => 'LinkExchange',
-    lotusnotes     => 'Lotus Notes',
-    lwp            => 'LWP::UserAgent',
-    lycos          => 'Lycos',
-    msn            => 'MSN',
-    msnmobile      => 'MSN Mobile',
-    puf            => 'puf',
-    robot          => 'robot',
-    slurp          => 'Yahoo! Slurp',
+    ahrefs          => 'Ahrefs',
+    altavista       => 'AltaVista',
+    askjeeves       => 'AskJeeves',
+    baidu           => 'Baidu Spider',
+    curl            => 'curl',
+    facebook        => 'Facebook',
+    getright        => 'GetRight',
+    google          => 'Google',
+    googleadsbot    => 'Google AdsBot',
+    googleadsense   => 'Google AdSense',
+    googlebotimage  => 'Googlebot Images',
+    googlebotnews   => 'Googlebot News',
+    googlebotvideo  => 'Googlebot Video',
+    googlemobile    => 'Google Mobile',
+    icab            => 'iCab',
+    infoseek        => 'InfoSeek',
+    linkchecker     => 'LinkChecker',
+    linkexchange    => 'LinkExchange',
+    lotusnotes      => 'Lotus Notes',
+    lwp             => 'LWP::UserAgent',
+    lycos           => 'Lycos',
+    mj12bot         => 'Majestic-12 DSearch',
+    msn             => 'MSN',
+    msnmobile       => 'MSN Mobile',
+    puf             => 'puf',
+    robot           => 'robot',
+    slurp           => 'Yahoo! Slurp',
     specialarchiver => 'archive.org_bot',
-    staroffice     => 'StarOffice',
-    webcrawler     => 'WebCrawler',
-    webtv          => 'WebTV',
-    wget           => 'wget',
-    yahoo          => 'Yahoo',
-    yandex         => 'Yandex',
-    yandeximages   => 'YandexImages',
+    staroffice      => 'StarOffice',
+    webcrawler      => 'WebCrawler',
+    webtv           => 'WebTV',
+    wget            => 'wget',
+    yahoo           => 'Yahoo',
+    yandex          => 'Yandex',
+    yandeximages    => 'YandexImages',
 );
 
 our @ROBOT_TESTS = qw(
     puf          curl        wget
     getright     robot       slurp
-    yahoo
+    yahoo        mj12bot
     altavista    lycos       infoseek
     lwp          webcrawler  linkexchange
     webtv        staroffice
@@ -334,7 +335,8 @@ sub _test {
         ( $major, $minor, $beta ) = split /\./, $1;
 
     }
-    elsif ($tests->{TRIDENT} && $ua =~ m{\b rv: ( [0-9\.]+ ) \b}x ) {
+    elsif ( $tests->{TRIDENT} && $ua =~ m{\b rv: ( [0-9\.]+ ) \b}x ) {
+
         # MSIE masking as Gecko really well ;)
         ( $major, $minor, $beta ) = split /\./, $1;
     }
@@ -342,30 +344,24 @@ sub _test {
     # Opera browsers
 
     $tests->{OPERA}
-        = (    index( $ua, "opera" ) != -1
-            || index( $ua, "opr/" ) != -1 );
+        = ( index( $ua, "opera" ) != -1 || index( $ua, "opr/" ) != -1 );
     $tests->{OPERA3}
-        = (    index( $ua, "opera 3" ) != -1
-            || index( $ua, "opera/3" ) != -1 );
-    $tests->{OPERA4}
-        = ( index( $ua, "opera 4" ) != -1 )
-            || ( index( $ua, "opera/4" ) != -1
-            && ( index( $ua, "nintendo dsi" ) == -1 ) );
-    $tests->{OPERA5}
-        = ( index( $ua, "opera 5" ) != -1 )
-            || ( index( $ua, "opera/5" ) != -1 );
-    $tests->{OPERA6}
-        = ( index( $ua, "opera 6" ) != -1 )
-            || ( index( $ua, "opera/6" ) != -1 );
-    $tests->{OPERA7}
-        = ( index( $ua, "opera 7" ) != -1 )
-            || ( index( $ua, "opera/7" ) != -1 );
+        = ( index( $ua, "opera 3" ) != -1 || index( $ua, "opera/3" ) != -1 );
+    $tests->{OPERA4} = ( index( $ua, "opera 4" ) != -1 )
+        || ( index( $ua, "opera/4" ) != -1
+        && ( index( $ua, "nintendo dsi" ) == -1 ) );
+    $tests->{OPERA5} = ( index( $ua, "opera 5" ) != -1 )
+        || ( index( $ua, "opera/5" ) != -1 );
+    $tests->{OPERA6} = ( index( $ua, "opera 6" ) != -1 )
+        || ( index( $ua, "opera/6" ) != -1 );
+    $tests->{OPERA7} = ( index( $ua, "opera 7" ) != -1 )
+        || ( index( $ua, "opera/7" ) != -1 );
 
- # Opera needs to be dealt with specifically
- # http://dev.opera.com/articles/view/opera-ua-string-changes/
- # http://my.opera.com/community/openweb/idopera/
- # Opera/9.80 (S60; SymbOS; Opera Mobi/320; U; sv) Presto/2.4.15 Version/10.00
- # Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.52 Safari/537.36 OPR/15.0.1147.100
+# Opera needs to be dealt with specifically
+# http://dev.opera.com/articles/view/opera-ua-string-changes/
+# http://my.opera.com/community/openweb/idopera/
+# Opera/9.80 (S60; SymbOS; Opera Mobi/320; U; sv) Presto/2.4.15 Version/10.00
+# Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.52 Safari/537.36 OPR/15.0.1147.100
 
     if ( $ua =~ m{\AOpera.*\sVersion/(\d*)\.(\d*)\z}i ) {
         $major = $1;
@@ -393,9 +389,8 @@ sub _test {
         && ( index( $ua, "like gecko" ) == -1 );
 
     $tests->{CHROME}
-        = ( !$tests->{OPERA}
-            && index( $ua, "chrome/" ) != -1
-            );#&& $ua =~ m{chrome/ ( [^.]* ) \. ( [^.]* )}x );
+        = ( !$tests->{OPERA} && index( $ua, "chrome/" ) != -1 )
+        ;    #&& $ua =~ m{chrome/ ( [^.]* ) \. ( [^.]* )}x );
     $tests->{SAFARI}
         = (    ( index( $ua, "safari" ) != -1 )
             || ( index( $ua, "applewebkit" ) != -1 ) )
@@ -488,7 +483,8 @@ sub _test {
 
     # Internet Explorer browsers
 
-    $tests->{IE} = ( $tests->{TRIDENT}
+    $tests->{IE}
+        = (    $tests->{TRIDENT}
             || index( $ua, "msie" ) != -1
             || index( $ua, 'microsoft internet explorer' ) != -1 );
     $tests->{IE3}    = ( $tests->{IE}  && $major == 3 );
@@ -552,7 +548,8 @@ sub _test {
 
     # Devices
 
-    $tests->{BLACKBERRY} = ( index( $ua, "blackberry" ) != -1
+    $tests->{BLACKBERRY}
+        = (    index( $ua, "blackberry" ) != -1
             || index( $ua, "bb10" ) != -1
             || index( $ua, "rim tablet os" ) != -1 );
     $tests->{IPHONE}   = ( index( $ua, "iphone" ) != -1 );
@@ -648,7 +645,7 @@ sub _test {
             || ( index( $ua, "android" ) != -1
             && index( $ua, "mobile" ) == -1
             && index( $ua, "opera" ) == -1 )
-            || ($tests->{FIREFOX} && index( $ua, "tablet" ) != -1)
+            || ( $tests->{FIREFOX} && index( $ua, "tablet" ) != -1 )
             || index( $ua, "kindle" ) != -1
             || index( $ua, "xoom" ) != -1
             || index( $ua, "flyer" ) != -1
@@ -689,7 +686,7 @@ sub _test {
     $self->{gecko_version} = undef;
     if ( $tests->{GECKO} ) {
         if ( $ua =~ /\([^)]*rv:([\w.\d]*)/ ) {
-            $self->{gecko_version} = $1;
+            $self->{gecko_version}  = $1;
             $self->{engine_version} = $1;
         }
     }
@@ -734,10 +731,7 @@ sub _test {
             pos( $ua ) - length $1, length $1;
         $self->{device_name} =~ s/; / /;
     }
-    elsif ( $ua
-        =~ /bb10; ([^;\)]+)/g
-        )
-    {
+    elsif ( $ua =~ /bb10; ([^;\)]+)/g ) {
         $self->{device_name} = 'BlackBerry ' . substr $self->{user_agent},
             pos( $ua ) - length $1, length $1;
         $self->{device_name} =~ s/Kbd/Q10/;
@@ -789,14 +783,15 @@ sub _robot_tests {
     $tests->{LINKEXCHANGE}   = ( index( $ua, "lecodechecker" ) != -1 );
     $tests->{LINKCHECKER}    = ( index( $ua, "linkchecker" ) != -1 );
     $tests->{LYCOS}          = ( index( $ua, "lycos" ) != -1 );
+    $tests->{MJ12BOT}        = ( index( $ua, "mj12bot/" ) != -1 );
     $tests->{PUF}            = ( index( $ua, "puf/" ) != -1 );
     $tests->{SCOOTER}        = ( index( $ua, "scooter" ) != -1 );
     $tests->{SLURP}          = ( index( $ua, "slurp" ) != -1 );
-    $tests->{SPECIALARCHIVER}          = ( index( $ua, "special_archiver" ) != -1 );
-    $tests->{WEBCRAWLER}     = ( index( $ua, "webcrawler" ) != -1 );
-    $tests->{WGET}           = ( index( $ua, "wget" ) != -1 );
-    $tests->{YANDEX}         = ( index( $ua, "yandexbot" ) != -1 );
-    $tests->{YANDEXIMAGES}   = ( index( $ua, "yandeximages" ) != -1 );
+    $tests->{SPECIALARCHIVER} = ( index( $ua, "special_archiver" ) != -1 );
+    $tests->{WEBCRAWLER}      = ( index( $ua, "webcrawler" ) != -1 );
+    $tests->{WGET}            = ( index( $ua, "wget" ) != -1 );
+    $tests->{YANDEX}          = ( index( $ua, "yandexbot" ) != -1 );
+    $tests->{YANDEXIMAGES}    = ( index( $ua, "yandeximages" ) != -1 );
 
     $tests->{ROBOT}
         = (    $tests->{AHREFS}
@@ -885,8 +880,8 @@ sub _os_tests {
     $tests->{WIN7}     = ( index( $ua, "nt 6.1" ) != -1 );
     $tests->{WIN8_0}   = ( index( $ua, "nt 6.2" ) != -1 );
     $tests->{WIN8_1}   = ( index( $ua, "nt 6.3" ) != -1 );
-    $tests->{WIN8}     = ( $tests->{WIN8_0} || $tests->{WIN8_1} );
-    $tests->{DOTNET}   = ( index( $ua, ".net clr" ) != -1 );
+    $tests->{WIN8} = ( $tests->{WIN8_0} || $tests->{WIN8_1} );
+    $tests->{DOTNET} = ( index( $ua, ".net clr" ) != -1 );
 
     $tests->{WINME} = ( index( $ua, "win 9x 4.90" ) != -1 );    # whatever
     $tests->{WIN32} = (
@@ -948,7 +943,7 @@ sub _os_tests {
     $tests->{EMACS} = ( index( $ua, 'emacs' ) != -1 );
     $tests->{OS2}   = ( index( $ua, 'os/2' ) != -1 );
 
-    if (index($ua, "samsung") < 0) {
+    if ( index( $ua, "samsung" ) < 0 ) {
         $tests->{SUN}  = ( index( $ua, "sun" ) != -1 );
         $tests->{SUN4} = ( index( $ua, "sunos 4" ) != -1 );
         $tests->{SUN5} = ( index( $ua, "sunos 5" ) != -1 );
@@ -1007,11 +1002,11 @@ sub _os_tests {
 
     $tests->{FIREFOXOS}
         = (    $tests->{FIREFOX}
-            && ($tests->{MOBILE} || $tests->{TABLET})
+            && ( $tests->{MOBILE} || $tests->{TABLET} )
             && !$tests->{ANDROID}
             && index( $ua, "fennec" ) == -1 );
 
-    $tests->{BB10} = ( index( $ua, "bb10" ) != -1 );
+    $tests->{BB10}        = ( index( $ua, "bb10" ) != -1 );
     $tests->{RIMTABLETOS} = ( index( $ua, "rim tablet os" ) != -1 );
 
     $tests->{PS3GAMEOS} = $tests->{PS3} && $tests->{NETFRONT};
@@ -1025,7 +1020,9 @@ sub _os_tests {
 sub os_version {
     my $self = shift;
 
-    if ( $self->ios && $self->{user_agent} =~ m{OS (\d*_\d*|\d*_\d*_\d*) like Mac} ) {
+    if (   $self->ios
+        && $self->{user_agent} =~ m{OS (\d*_\d*|\d*_\d*_\d*) like Mac} )
+    {
         my $version = $1;
         $version =~ s{_}{.}g;
         return $version;
@@ -1035,14 +1032,15 @@ sub os_version {
         return join '.', $1, $2, $3;
     }
 
-    # firefox in mac
-    # "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:25.0) Gecko/20100101 Firefox/25.0"
+# firefox in mac
+# "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:25.0) Gecko/20100101 Firefox/25.0"
     if ( $self->mac && $self->{user_agent} =~ m{ X \s (\d\d\.\d)}x ) {
         return $1;
     }
 
     if (   $self->winphone
-       && $self->{user_agent} =~ m{Windows \s Phone \s \w{0,2} \s{0,1} (\d+\.\d+);}x )
+        && $self->{user_agent}
+        =~ m{Windows \s Phone \s \w{0,2} \s{0,1} (\d+\.\d+);}x )
     {
         return $1;
     }
@@ -1119,10 +1117,10 @@ sub os_string {
     return 'RIM Tablet OS'               if $self->rimtabletos;
     return 'Playstation 3 GameOS'        if $self->ps3gameos;
     return 'Playstation Portable GameOS' if $self->pspgameos;
-    return 'iOS' if $self->iphone || $self->ipod || $self->ipad;
-    return 'Mac OS X'                    if $self->macosx;
-    return 'Mac'                         if $self->mac;
-    return 'OS2'                         if $self->os2;
+    return 'iOS'      if $self->iphone || $self->ipod || $self->ipad;
+    return 'Mac OS X' if $self->macosx;
+    return 'Mac'      if $self->mac;
+    return 'OS2'      if $self->os2;
     return undef;
 }
 
@@ -1513,7 +1511,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 1.73
+version 1.74
 
 =head1 SYNOPSIS
 
@@ -1928,6 +1926,8 @@ value. This is by no means a complete list of robots that exist on the Web.
 
 =head3 lycos
 
+=head3 mj12bot
+
 =head3 msn (same as bing)
 
 =head3 puf
